# Reset_feedback

*Tip: Dieses Plug-in hat den selben Effekt als ein Feedback Item für 0 ms zu präsentieren.*

Wenn Sie Ihre Feedbackvariablen nicht zurücksetzen, könnten Sie Ihr Feedback mit Reaktionen beeinflussen, die nicht relevant für die Aufgabe sind. Zum Beispiel Tasten, die in der Instruktionsphase gepresst wurden, können das Feedback während des ersten Blocks beeinflussen. Daher sollten Sie die Feedbackvariablen an gegebener Stelle zurücksetzen.

Dieses Plug-in wird folgende Variablen zurück auf 0 setzen:

- `total_response_time`
- `total_response`
- `acc`
- `accuracy`
- `avg_rt`
- `average_response_time`

Für mehr Informationen, besuchen Sie:

- <http://osdoc.cogsci.nl/3.2/manual/stimuli/visual/>
